<?xml version="1.0" encoding="UTF-8"?>
<!-- Vektis ei BM801val 1.0 - 10-08-2017 -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:bo="http://ei.vektis.nl/betaalopdracht/basisschema/v1_0" xmlns:bm801="http://ei.vektis.nl/betaalopdrachtmondzorg/bm801/v1_0" xmlns:bm801val="http://ei.vektis.nl/betaalopdrachtmondzorg/bm801val/v1_0">

<!-- Hieronder aanroepen alle verbandscontroles, voorbeeld 1e van BM801:      <xsl:import href="rc8028.xslt"/>. -->
  	<xsl:import href="rc8028.xslt"/>
 	<xsl:import href="rc8920.xslt"/>
 	<xsl:import href="rc8987.xslt"/>
 	<xsl:import href="rc8988.xslt"/>
 	<xsl:import href="rc8989.xslt"/>
 	<xsl:import href="rc8990.xslt"/>
 	<xsl:import href="rc8991.xslt"/>
 	
 	
	<!-- Uitvoer is bm801val (val = validated) bericht met Retourcodes. -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
	
	<!-- Header elementen voorkomend in RBC verbandscontroles en referentiecontroles (deels). -->
	<xsl:variable name="Berichtcode" select="//bm801:Bericht/bm801:Header/bm801:Berichtcode"/>
	<xsl:variable name="BerichtSoort" select="//bm801:Bericht/bm801:Header/bm801:BerichtSoort"/> 
	<xsl:variable name="Indiener" select="//bm801:Bericht/bm801:Header/bm801:Indiener"/>
	<xsl:variable name="Aanmaakdatum" select="translate(//bm801:Bericht/bm801:Header/bm801:Aanmaakdatum, '-', '')"/>
	
	<xsl:template match="//bm801:Bericht">
		<bm801val:Bericht>
			<xsl:attribute name="xsi:schemaLocation">http://ei.vektis.nl/betaalopdrachtmondzorg/bm801val/v1_0 BM801val.xsd</xsl:attribute>
			<xsl:apply-templates select="bm801:Header"/>
			<xsl:apply-templates select="bm801:Betaalopdrachten"/>
		</bm801val:Bericht>
	</xsl:template>
	
	<xsl:template match="bm801:Header">
		<bm801val:Header>
			<xsl:apply-templates select="bm801:Berichtcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:BerichtVersie" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:BerichtSubversie" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:BerichtSoort" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:Indiener" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:AfzenderReferentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:Aanmaakdatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:SomTotaalbedragDC"/>
			
  	       	<bm801val:Retourcodes>
				
				<xsl:variable name="BerichtSoort" select="bm801:BerichtSoort"/>
					
				<!-- retourcode 8028: Soort bericht ontbreekt of is onjuist -->
				<xsl:variable name="rc8028">
					<xsl:call-template name="rc8028">
						<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:copy-of select="$rc8028"/>
				
				<!-- retourcode 8920: Aanmaakdatum moet kleiner zijn dan of gelijk zijn aan de huidige datum. -->
				<xsl:variable name="rc8920">
					<xsl:call-template name="rc8920">
						<xsl:with-param name="Aanmaakdatum" select="$Aanmaakdatum"/>
						<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
					</xsl:call-template>
				</xsl:variable> 
				<xsl:copy-of select="$rc8920"/>
					
				<!-- retourcode 8987: De som totaalbedrag in de Header moet gelijk zijn aan de som van alle totaalbedragen van alle betaalopdrachten van alle begunstigden, rekening houdend met debet/credit.  -->
				<xsl:variable name="rc8987">
					<xsl:call-template name="rc8987">
						<xsl:with-param name="Bedrag" select="bm801:SomTotaalbedragDC/bo:Bedrag"/>
						<xsl:with-param name="DebetCredit" select="bm801:SomTotaalbedragDC/bo:DebetCredit"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:copy-of select="$rc8987"/>
				
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc8028='' and $rc8920='' and $rc8987=''">
					<bo:Retourcode>0200</bo:Retourcode>
				</xsl:if>
					
					
			</bm801val:Retourcodes>
		</bm801val:Header>
	</xsl:template>
	
	<xsl:template match="bm801:SomTotaalbedragDC">
		<bm801val:SomTotaalbedragDC>
			<xsl:copy-of select="bo:Bedrag"/>
			<xsl:copy-of select="bo:DebetCredit"/>
		</bm801val:SomTotaalbedragDC>
	</xsl:template>
	
	<xsl:template match="bm801:Betaalopdrachten">	
		<bm801val:Betaalopdrachten>
			<xsl:apply-templates select="bm801:Betaalopdracht"/>
		</bm801val:Betaalopdrachten>
	</xsl:template>
	
	<xsl:template match="bm801:Betaalopdracht">
		<bm801val:Betaalopdracht>
			<xsl:apply-templates select="bm801:UzoviNummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:BetaalopdrachtCategorie" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:Begunstigde" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:TypeBegunstigde" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:Iban" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:Tenaamstelling" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:Woonplaats" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:Begindatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:Einddatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="bm801:HonorariumkostenDC"/>
			<xsl:apply-templates select="bm801:TechniekkostenDC" />
			<xsl:apply-templates select="bm801:ReiskostenDC" />
			<xsl:apply-templates select="bm801:TotaalbedragDC"/>
			<xsl:apply-templates select="bm801:Betalingskenmerk" mode="copy-if-exists"/>

			<bm801val:Retourcodes>
				
				<xsl:variable name="Begindatum" select="translate(bm801:Begindatum, '-', '')"/>
				<xsl:variable name="Einddatum" select="translate(bm801:Einddatum, '-', '')"/>
				
				
				<!-- retourcode 8988: De waarde van het IBAN nummer moet voldoen aan Modulo 97 proef/validatie. -->
				<xsl:variable name="rc8988">
					<xsl:call-template name="rc8988">
						<xsl:with-param name="Iban" select="bm801:Iban"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:copy-of select="$rc8988"/>
				
				<!-- retourcode 8989: De begindatum moet gelijk aan of vroeger zijn dan de Aanmaakdatum uit de Header. -->
				<xsl:variable name="rc8989">
					<xsl:call-template name="rc8989">
						<xsl:with-param name="Aanmaakdatum" select="$Aanmaakdatum"/>
						<xsl:with-param name="Begindatum" select="$Begindatum"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:copy-of select="$rc8989"/>
				
				<!-- retourcode 8990: Einddatum moet gelijk aan of later zijn dan de begindatum (datums binnen Betaalopdracht). -->
				<xsl:variable name="rc8990">
					<xsl:call-template name="rc8990">
						<xsl:with-param name="Begindatum" select="$Begindatum"/>
						<xsl:with-param name="Einddatum" select="$Einddatum"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:copy-of select="$rc8990"/>
				
				<!-- retourcode 8991: Het totaalbedrag in de Betaalopdracht moet gelijk zijn aan de som van honorariumkosten, techniekkosten en reiskosten, rekening houdend met debet/credit.  -->
				<xsl:variable name="rc8991">
					<xsl:call-template name="rc8991">
						<xsl:with-param name="Bedrag" select="bm801:TotaalbedragDC/bo:Bedrag"/>
						<xsl:with-param name="DebetCredit" select="bm801:TotaalbedragDC/bo:DebetCredit"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:copy-of select="$rc8991"/>
				
				
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc8988='' and $rc8989='' and $rc8990='' and $rc8991=''">
					<bo:Retourcode>0200</bo:Retourcode>
				</xsl:if>

			</bm801val:Retourcodes>		
		</bm801val:Betaalopdracht>
	</xsl:template>

	<xsl:template match="bm801:HonorariumkostenDC">
		<bm801val:HonorariumkostenDC>
			<xsl:copy-of select="bo:Bedrag"/>
			<xsl:copy-of select="bo:DebetCredit"/>
		</bm801val:HonorariumkostenDC>
	</xsl:template>

	<xsl:template match="bm801:TechniekkostenDC">
		<bm801val:TechniekkostenDC>
			<xsl:copy-of select="bo:Bedrag"/>
			<xsl:copy-of select="bo:DebetCredit"/>
		</bm801val:TechniekkostenDC>
	</xsl:template>
	
	<xsl:template match="bm801:ReiskostenDC">
		<bm801val:ReiskostenDC>
			<xsl:copy-of select="bo:Bedrag"/>
			<xsl:copy-of select="bo:DebetCredit"/>
		</bm801val:ReiskostenDC>
	</xsl:template>
	
	<xsl:template match="bm801:TotaalbedragDC">
		<bm801val:TotaalbedragDC>
			<xsl:copy-of select="bo:Bedrag"/>
			<xsl:copy-of select="bo:DebetCredit"/>
		</bm801val:TotaalbedragDC>
	</xsl:template>
	
	<!-- Copy template: als een enkel element voorkomt is, wordt deze gekopieerd in de opgegeven namespace -->
	<xsl:template match="*" mode="copy-if-exists">
		<xsl:param name="NameSpacePrefix" select="'bm801val:'"/>
		<xsl:if test=".">
			<xsl:element name="{concat($NameSpacePrefix,local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>
