<!-- 

Bron: https://nl.wikipedia.org/wiki/International_Bank_Account_Number

Een Iban wordt gevalideerd door het om te zetten naar cijfers en dan de restwaarde te bepalen als het geheeltallig gedeeld wordt door 97. Die restwaarde moet gelijk zijn aan 1.
Het controle algoritme van Iban is als volgt:

1. valideer de samenstelling. Dit is mogelijk in de XSD en wordt daarom hier overgeslagen
2. verplaats de eerste 4 karakters naar het einde
3. vervang elke letter door 2 cijfers, waarbij A = 10, B = 11, ..., Z = 35
4. bereken dan het getal modulo 97. Als de restwaarde 1 is, dan klopt het nummer op basis van het controlecijfer en kan het Iban valide zijn

-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"	xmlns:bo="http://ei.vektis.nl/betaalopdracht/basisschema/v1_0" xmlns:bm801="http://ei.vektis.nl/betaalopdrachtmondzorg/bm801/v1_0" >
<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<!-- retourcode 8988: De waarde van het IBAN nummer moet voldoen aan Modulo 97 proef/validatie. -->
	<xsl:template name="rc8988">
		<xsl:param name="Iban"/>
		<xsl:variable name="Stap2">
			<xsl:call-template name="VerplaatsKarakters">
				<xsl:with-param name="IbanKarakters" select="$Iban"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="Stap3">
			<xsl:call-template name="VervangLetters">
				<xsl:with-param name="text" select="$Stap2"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="Stap4">
			<xsl:call-template name="Modulo">
				<xsl:with-param name="number" select="$Stap3"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:if test="$Stap4 != 1">
			<bo:Retourcode>8988</bo:Retourcode>
		</xsl:if>
	</xsl:template>

	<xsl:template name="VerplaatsKarakters">
		<xsl:param name="IbanKarakters"/>
		<xsl:value-of select="concat(substring($IbanKarakters,5), substring($IbanKarakters,1,4))"/>
	</xsl:template>

	<xsl:template name="VervangLetters">
		<xsl:param name="text"/>
		<xsl:param name="index" select="1"/>
		<xsl:param name="char" select="substring($text, $index, 1)"/>
		<xsl:choose>
			<xsl:when test="string-length($text) &gt;= $index">
				<xsl:choose>
					<xsl:when test="not(number($char)=number($char))">
						<!-- Controleer of het een getal is. In geval val een karakter => NaN = NaN is onwaar -->
						<xsl:call-template name="VervangLetters">
							<xsl:with-param name="text">
								<xsl:variable name="translation">
									<xsl:call-template name="VervangLetterMetCijfer">
										<xsl:with-param name="char" select="$char"/>
									</xsl:call-template>
								</xsl:variable>
								<xsl:value-of select="concat(substring($text, 0, $index), $translation, substring($text, $index+1, string-length($text)))"/>
							</xsl:with-param>
							<xsl:with-param name="index" select="$index+2"/>
							<xsl:with-param name="char" select="substring($text, $index+1, 1)"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="VervangLetters">
							<xsl:with-param name="text" select="$text"/>
							<xsl:with-param name="char" select="substring($text, $index+1, 1)"/>
							<xsl:with-param name="index" select="$index+1"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$text"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="VervangLetterMetCijfer">
		<xsl:param name="char"/>
		<xsl:choose>
			<xsl:when test="$char = 'A'">10</xsl:when>
			<xsl:when test="$char = 'B'">11</xsl:when>
			<xsl:when test="$char = 'C'">12</xsl:when>
			<xsl:when test="$char = 'D'">13</xsl:when>
			<xsl:when test="$char = 'E'">14</xsl:when>
			<xsl:when test="$char = 'F'">15</xsl:when>
			<xsl:when test="$char = 'G'">16</xsl:when>
			<xsl:when test="$char = 'H'">17</xsl:when>
			<xsl:when test="$char = 'I'">18</xsl:when>
			<xsl:when test="$char = 'J'">19</xsl:when>
			<xsl:when test="$char = 'K'">20</xsl:when>
			<xsl:when test="$char = 'L'">21</xsl:when>
			<xsl:when test="$char = 'M'">22</xsl:when>
			<xsl:when test="$char = 'N'">23</xsl:when>
			<xsl:when test="$char = 'O'">24</xsl:when>
			<xsl:when test="$char = 'P'">25</xsl:when>
			<xsl:when test="$char = 'Q'">26</xsl:when>
			<xsl:when test="$char = 'R'">27</xsl:when>
			<xsl:when test="$char = 'S'">28</xsl:when>
			<xsl:when test="$char = 'T'">29</xsl:when>
			<xsl:when test="$char = 'U'">30</xsl:when>
			<xsl:when test="$char = 'V'">31</xsl:when>
			<xsl:when test="$char = 'W'">32</xsl:when>
			<xsl:when test="$char = 'X'">33</xsl:when>
			<xsl:when test="$char = 'Y'">34</xsl:when>
			<xsl:when test="$char = 'Z'">35</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="Modulo">
		<!--Deze tempate is in het leven geroepen omdat een modulo op 'grote' getallen een verkeerde uitkomst geeft -->
		<xsl:param name="number" select="."/>
		<xsl:param name="division" select="97"/>
		<xsl:choose>
			<xsl:when test="not($number> 9999999999999999)">
				<xsl:value-of select="$number mod $division"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="length" select="string-length($number) - 1"/>
				<xsl:variable name="part1" select="substring($number, 1, $length)"/>
				<xsl:variable name="mod1">
					<xsl:call-template name="Modulo">
						<xsl:with-param name="number" select="$part1"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:variable name="part2" select="substring($number, $length +1)"/>
				<xsl:variable name="mod2" select="$part2 mod $division"/>
				<xsl:value-of select="(10*$mod1 + $mod2) mod $division"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>
