<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"	xmlns:bo="http://ei.vektis.nl/betaalopdracht/basisschema/v1_0" xmlns:bm801="http://ei.vektis.nl/betaalopdrachtmondzorg/bm801/v1_0" >

	<!-- retourcode 8991: Het totaalbedrag in de Betaalopdracht moet gelijk zijn aan de som van honorariumkosten, techniekkosten en reiskosten, rekening houdend met debet/credit.  -->
	<xsl:template name="rc8991">

		<xsl:param name="Bedrag"/>
		<xsl:param name="DebetCredit"/>

		<xsl:variable name="HonorariumkostenDebet">
		<xsl:choose>
			<xsl:when test="number((bm801:HonorariumkostenDC[bo:DebetCredit = 'D']/bo:Bedrag))">
				<xsl:value-of select="(bm801:HonorariumkostenDC[bo:DebetCredit = 'D']/bo:Bedrag)" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="0" />
			</xsl:otherwise>
		</xsl:choose>		
		</xsl:variable>

		<xsl:variable name="HonorariumkostenCredit">
		<xsl:choose>
			<xsl:when test="number((bm801:HonorariumkostenDC[bo:DebetCredit = 'C']/bo:Bedrag))">
				<xsl:value-of select="(bm801:HonorariumkostenDC[bo:DebetCredit = 'C']/bo:Bedrag)" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="0" />
			</xsl:otherwise>
		</xsl:choose>		
		</xsl:variable>

		<xsl:variable name="TechniekkostenDebet">
		<xsl:choose>
			<xsl:when test="number((bm801:TechniekkostenDC[bo:DebetCredit = 'D']/bo:Bedrag))">
				<xsl:value-of select="(bm801:TechniekkostenDC[bo:DebetCredit = 'D']/bo:Bedrag)" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="0" />
			</xsl:otherwise>
		</xsl:choose>		
		</xsl:variable>

		<xsl:variable name="TechniekkostenCredit">
		<xsl:choose>
			<xsl:when test="number((bm801:TechniekkostenDC[bo:DebetCredit = 'C']/bo:Bedrag))">
				<xsl:value-of select="(bm801:TechniekkostenDC[bo:DebetCredit = 'C']/bo:Bedrag)" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="0" />
			</xsl:otherwise>
		</xsl:choose>		
		</xsl:variable>


		<xsl:variable name="ReiskostenDebet">
		<xsl:choose>
			<xsl:when test="number((bm801:ReiskostenDC[bo:DebetCredit = 'D']/bo:Bedrag))">
				<xsl:value-of select="(bm801:ReiskostenDC[bo:DebetCredit = 'D']/bo:Bedrag)" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="0" />
			</xsl:otherwise>
		</xsl:choose>		
		</xsl:variable>

		<xsl:variable name="ReiskostenCredit">
		<xsl:choose>
			<xsl:when test="number((bm801:ReiskostenDC[bo:DebetCredit = 'C']/bo:Bedrag))">
				<xsl:value-of select="(bm801:ReiskostenDC[bo:DebetCredit = 'C']/bo:Bedrag)" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="0" />
			</xsl:otherwise>
		</xsl:choose>		
		</xsl:variable>

		<xsl:variable name="Saldo" select="$HonorariumkostenDebet - $HonorariumkostenCredit + $TechniekkostenDebet - $TechniekkostenCredit + $ReiskostenDebet - $ReiskostenCredit"/>
		
		<!-- Eventueel onderstaande regels, hier commentaar, gebruiken om de inhoud van variabelen te tonen in een Output bestand.
		<HonorariumkostenDebet><xsl:value-of select="$HonorariumkostenDebet"/></HonorariumkostenDebet>
		<HonorariumkostenCredit><xsl:value-of select="$HonorariumkostenCredit"/></HonorariumkostenCredit>
		<TechniekkostenDebet><xsl:value-of select="$TechniekkostenDebet"/></TechniekkostenDebet>
		<TechniekkostenCredit><xsl:value-of select="$TechniekkostenCredit"/></TechniekkostenCredit>
		<ReiskostenDebet><xsl:value-of select="$ReiskostenDebet"/></ReiskostenDebet>
		<ReiskostenCredit><xsl:value-of select="$ReiskostenCredit"/></ReiskostenCredit>
		<Saldo><xsl:value-of select="$Saldo"/></Saldo> -->
		
		
		<!-- Controleren of Bedrag overeenkomt met saldo bedragen -->
		<xsl:if test="normalize-space($DebetCredit) = 'D'">
			<xsl:if test="normalize-space($Saldo) != normalize-space($Bedrag)">
				<bo:Retourcode>8991</bo:Retourcode>
			</xsl:if>
		</xsl:if>
		<!-- In het geval van Credit moet het bedrag negatief worden gemaakt -->
		<xsl:if test="normalize-space($DebetCredit) = 'C'">
			<xsl:if test="normalize-space($Saldo) != normalize-space(0-$Bedrag)">
				<bo:Retourcode>8991</bo:Retourcode>
			</xsl:if>
		</xsl:if>

	</xsl:template>
</xsl:stylesheet>
